@@ -27,7 +27,7 @@ import aiohttp
 import typing
 
 
-async def fetch_query(key: str, query: str, keys: typing.Iterable = None) -> dict:
+async def fetch_query(key: str, query: str, keys: typing.Iterable = None) -> typing.Any:
     """
     Fetches a given query from the gql api using a provided api key.
 
@@ -167,6 +167,28 @@ async def within_war_range(
     return nations
 
 
+async def nations_pages(key: str) -> int:
+    query = """
+    nations(first: 500) {
+        paginatorInfo {
+            lastPage
+        }
+    }
+    """
+    return await fetch_query(key, query, keys=["nations", "paginatorInfo", "lastPage"])
+
+
+async def alliances_pages(key: str) -> int:
+    query = """
+    alliances(first: 50) {
+        paginatorInfo {
+            lastPage
+        }
+    }
+    """
+    return await fetch_query(key, query, keys=["alliances", "paginatorInfo", "lastPage"])
+
+
 async def alliance_details(key: str, alliance: int) -> dict:
     query = f"""
     alliances(id:{alliance}, first:1) {{
@@ -274,18 +296,48 @@ async def alliance_treaties(key: str, alliance: int) -> dict:
     return await fetch_query(key, query, keys=("alliances", "data"))
 
 
-async def alliance_members(key: str, alliance: int) -> dict:
+async def alliance_members(key: str, alliance: int) -> list:
     query = f"""
     alliances(id:{alliance}, first:1){{
         data{{
             nations {{
                 id
+                alliance_position
+                nation_name
+                leader_name
+                score
+                warpolicy
+                dompolicy
+                color
+                num_cities
+                flag
+                espionage_available
+                last_active
+                date
+                soldiers
+                tanks
+                aircraft
+                ships
+                missiles
+                nukes
+                treasures {{
+                    name
+                    bonus
+                }}
+                offensive_wars {{
+                    turnsleft
+                    winner
+                }}
+                defensive_wars {{
+                    turnsleft
+                    winner
+                }}
             }}
         }}
     }}
     """
 
-    return await fetch_query(key, query, keys=("alliances", "data"))
+    return await fetch_query(key, query, keys=("alliances", "data", "nations"))
 
 
 class QueryHandler:
@@ -306,7 +358,7 @@ class QueryHandler:
         """
         self._queries.add(query)
 
-    async def fetch_query(self, query: str = None, *args, **kwargs) -> dict:
+    async def fetch_query(self, query: str = None, *args, **kwargs) -> typing.Any:
         """
         Fetches all added queries in one go.
 
@@ -316,7 +368,25 @@ class QueryHandler:
         return await fetch_query(self.key, query, *args, **kwargs)
 
     async def within_war_range(self, *args, **kwargs) -> list:
-        """
-        Reference for coro within_war_range where api key is passed from the class.
-        """
         return await within_war_range(self.key, *args, **kwargs)
+
+    async def nations_pages(self) -> int:
+        return await nations_pages(self.key)
+
+    async def alliances_pages(self) -> int:
+        return await alliances_pages(self.key)
+
+    async def alliance_details(self, alliance: int) -> dict:
+        return await alliance_details(self.key, alliance)
+
+    async def alliance_bank_contents(self, alliance: int) -> dict:
+        return await alliance_bank_contents(self.key, alliance)
+
+    async def alliance_bank_records(self, alliance: int) -> dict:
+        return await alliance_bank_records(self.key, alliance)
+
+    async def alliance_treaties(self, alliance: int) -> dict:
+        return await alliance_treaties(self.key, alliance)
+
+    async def alliance_members(self, alliance: int) -> list:
+        return await alliance_members(self.key, alliance)
